@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,10 +36,12 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.tpu_v1.services.tpu import pagers
 from google.cloud.tpu_v1.types import cloud_tpu
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import TpuTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, TpuTransport
 from .transports.grpc import TpuGrpcTransport
 from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
 
@@ -56,7 +58,10 @@ class TpuClientMeta(type):
     _transport_registry["grpc"] = TpuGrpcTransport
     _transport_registry["grpc_asyncio"] = TpuGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[TpuTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[TpuTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,11 +169,15 @@ class TpuClient(metaclass=TpuClientMeta):
 
     @staticmethod
     def accelerator_type_path(
-        project: str, location: str, accelerator_type: str,
+        project: str,
+        location: str,
+        accelerator_type: str,
     ) -> str:
         """Returns a fully-qualified accelerator_type string."""
         return "projects/{project}/locations/{location}/acceleratorTypes/{accelerator_type}".format(
-            project=project, location=location, accelerator_type=accelerator_type,
+            project=project,
+            location=location,
+            accelerator_type=accelerator_type,
         )
 
     @staticmethod
@@ -181,10 +190,16 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def node_path(project: str, location: str, node: str,) -> str:
+    def node_path(
+        project: str,
+        location: str,
+        node: str,
+    ) -> str:
         """Returns a fully-qualified node string."""
         return "projects/{project}/locations/{location}/nodes/{node}".format(
-            project=project, location=location, node=node,
+            project=project,
+            location=location,
+            node=node,
         )
 
     @staticmethod
@@ -198,11 +213,15 @@ class TpuClient(metaclass=TpuClientMeta):
 
     @staticmethod
     def tensor_flow_version_path(
-        project: str, location: str, tensor_flow_version: str,
+        project: str,
+        location: str,
+        tensor_flow_version: str,
     ) -> str:
         """Returns a fully-qualified tensor_flow_version string."""
         return "projects/{project}/locations/{location}/tensorFlowVersions/{tensor_flow_version}".format(
-            project=project, location=location, tensor_flow_version=tensor_flow_version,
+            project=project,
+            location=location,
+            tensor_flow_version=tensor_flow_version,
         )
 
     @staticmethod
@@ -215,7 +234,9 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -228,9 +249,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -239,9 +264,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -250,9 +279,13 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -261,10 +294,14 @@ class TpuClient(metaclass=TpuClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -525,12 +562,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListNodesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -617,7 +662,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -732,7 +782,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -834,7 +889,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -916,7 +976,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -998,7 +1063,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1080,7 +1150,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1182,12 +1257,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListTensorFlowVersionsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1276,7 +1359,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1368,12 +1456,20 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAcceleratorTypesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1462,7 +1558,12 @@ class TpuClient(metaclass=TpuClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1483,7 +1584,9 @@ class TpuClient(metaclass=TpuClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-tpu",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-tpu",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
